pub fn from_explicit(name: &str) -> DetectionResultExpand description
Create a detection result from an explicit agent name.
Used when the user specifies --agent=<name> on the command line.
pub fn from_explicit(name: &str) -> DetectionResultCreate a detection result from an explicit agent name.
Used when the user specifies --agent=<name> on the command line.